@@ -25,8 +25,8 @@ import com.codahale.metrics.Timer;
 
 public class HoodieDeltaStreamerMetrics {
 
-  private HoodieWriteConfig config = null;
-  private String tableName = null;
+  private HoodieWriteConfig config;
+  private String tableName;
 
   public String overallTimerName = null;
   public String hiveSyncTimerName = null;
