@@ -161,14 +161,20 @@ public class UtilitiesTestBase {
     // to get hold of resources bundled with jar
     private static ClassLoader classLoader = Helpers.class.getClassLoader();
 
-    public static void copyToDFS(String testResourcePath, FileSystem fs, String targetPath) throws IOException {
+    public static String readFile(String testResourcePath) throws IOException {
       BufferedReader reader =
           new BufferedReader(new InputStreamReader(classLoader.getResourceAsStream(testResourcePath)));
-      PrintStream os = new PrintStream(fs.create(new Path(targetPath), true));
+      StringBuffer sb = new StringBuffer();
       String line;
       while ((line = reader.readLine()) != null) {
-        os.println(line);
+        sb.append(line + "\n");
       }
+      return sb.toString();
+    }
+
+    public static void copyToDFS(String testResourcePath, FileSystem fs, String targetPath) throws IOException {
+      PrintStream os = new PrintStream(fs.create(new Path(targetPath), true));
+      os.print(readFile(testResourcePath));
       os.flush();
       os.close();
     }
